@@ -2,7 +2,7 @@ context("geoms")
 
 test_that("geoms work with basic parameters", {
   expect_silent( {
-    ggplot2::ggplot(G20, ggplot2::aes(
+    p <- ggplot2::ggplot(G20, ggplot2::aes(
       fill = hdi,
       area = gdp_mil_usd,
       subgroup = econ_classification,
@@ -60,5 +60,15 @@ test_that("geoms work with basic parameters", {
       ) +
       ggplot2::facet_grid(econ_classification ~ region) +
       ggplot2::scale_colour_gradient(low = "red", high = "green")
+    print(p)
   })
 })
+
+test_that("geom_treemap_subgroup_text works with a colour aesthetic", {
+  expect_silent( {
+    p <- ggplot2::ggplot(G20, ggplot2::aes(area = gdp_mil_usd, fill = hdi, subgroup = hemisphere, subgroup2 = region, subgroup3 = country)) + 
+      treemapify::geom_treemap() +
+      treemapify::geom_treemap_subgroup3_text(ggplot2::aes(colour = region))
+    print(p)
+  } )
+})
